@@ -11,7 +11,6 @@ import com.jidesoft.utils.ReflectionUtils;
 import com.sun.java.swing.plaf.windows.WindowsClassicLookAndFeel;
 import com.sun.java.swing.plaf.windows.WindowsComboBoxUI;
 import sun.awt.image.SunWritableRaster;
-import sun.awt.image.SurfaceManager;
 import sun.awt.windows.ThemeReader;
 import sun.security.action.GetPropertyAction;
 import sun.swing.CachedPainter;
@@ -574,16 +573,7 @@ public class XPStyle {
          * @param state which state to paint
          */
         public void paintSkin(Graphics g, int dx, int dy, int dw, int dh, State state) {
-            if (ThemeReader.isGetThemeTransitionDurationDefined()
-                    && component instanceof JComponent
-                    && SwingUtilities.getAncestorOfClass(CellRendererPane.class,
-                    component) == null) {
-                AnimationController.paintSkin((JComponent) component, this,
-                        g, dx, dy, dw, dh, state);
-            }
-            else {
-                paintSkinRaw(g, dx, dy, dw, dh, state);
-            }
+            paintSkinRaw(g, dx, dy, dw, dh, state);
         }
 
         /**
