@@ -26,7 +26,6 @@ import com.jidesoft.swing.JideTabbedPane;
 import com.jidesoft.utils.ProductNames;
 import com.jidesoft.utils.SecurityUtils;
 import com.jidesoft.utils.SystemInfo;
-import com.sun.java.swing.plaf.windows.WindowsLookAndFeel;
 
 import javax.swing.*;
 import javax.swing.plaf.BorderUIResource;
@@ -195,6 +194,11 @@ public class LookAndFeelFactory implements ProductNames {
      */
     public static final String A03_LNF = "a03.swing.plaf.A03LookAndFeel";
 
+    /**
+     * Class name of Darcula L&F.
+     */
+    public static final String DARCULA_LNF = "com.bulenkov.darcula.DarculaLaf";
+
     /**
      * Class name of Pgs L&F.
      */
@@ -533,10 +537,10 @@ public class LookAndFeelFactory implements ProductNames {
             if (_defaultStyle == -1) {
                 int suggestedStyle;
                 try {
-                    if (SystemInfo.isWindowsVistaAbove() && UIManager.getLookAndFeel() instanceof WindowsLookAndFeel && SystemInfo.isJdk6Above()) {
+                    if (SystemInfo.isWindowsVistaAbove() && isWindowsLookAndFeel(UIManager.getLookAndFeel()) && SystemInfo.isJdk6Above()) {
                         suggestedStyle = EXTENSION_STYLE_OFFICE2007;
                     }
-                    else if (XPUtils.isXPStyleOn() && UIManager.getLookAndFeel() instanceof WindowsLookAndFeel) {
+                    else if (XPUtils.isXPStyleOn() && isWindowsLookAndFeel(UIManager.getLookAndFeel())) {
                         suggestedStyle = EXTENSION_STYLE_OFFICE2003;
                     }
                     else {
@@ -845,7 +849,7 @@ public class LookAndFeelFactory implements ProductNames {
                     break;
             }
         }
-        else if (lnf instanceof WindowsLookAndFeel) {
+        else if (isWindowsLookAndFeel(lnf)) {
             switch (style) {
                 case EXTENSION_STYLE_OFFICE2007:
                     VsnetWindowsUtils.initComponentDefaultsWithMenu(uiDefaults);
@@ -1340,6 +1344,12 @@ public class LookAndFeelFactory implements ProductNames {
         if (lnfClassName.endsWith("LookAndFeel")) {
             return lnfClassName.substring(start, lnfClassName.length() - "LookAndFeel".length());
         }
+        else if (lnfClassName.endsWith("Laf")) {
+            return lnfClassName.substring(start, lnfClassName.length() - "Laf".length());
+        }
+        else if (lnfClassName.endsWith("Lnf")) {
+            return lnfClassName.substring(start, lnfClassName.length() - "Lnf".length());
+        }
         return null;
     }
 
@@ -1351,7 +1361,6 @@ public class LookAndFeelFactory implements ProductNames {
      * if the L&F is installed.
      *
      * @param lnfName the L&F name.
-     *
      * @return <tt>true</tt> if the L&F is in classpath, <tt>false</tt> otherwise
      */
     public static boolean isLnfInstalled(String lnfName) {
@@ -1378,7 +1387,6 @@ public class LookAndFeelFactory implements ProductNames {
      * Checks if the L&F is the L&F or a subclass of the L&F.
      *
      * @param lnf the full class name of the L&F (including the package).
-     *
      * @return true or false.
      */
     public static boolean isLnfInUse(String lnf) {
@@ -1482,7 +1490,6 @@ public class LookAndFeelFactory implements ProductNames {
      * Returns whether Plastic3D L&F is in classpath
      *
      * @return <tt>true</tt> Plastic3D L&F is in classpath, <tt>false</tt> otherwise
-     *
      * @deprecated replace by {@link #isPlastic3DLnfInstalled()}
      */
     @Deprecated
@@ -1517,6 +1524,15 @@ public class LookAndFeelFactory implements ProductNames {
         return isLnfInstalled(A03_LNF);
     }
 
+    /**
+     * Returns whether Darcula L&F is in classpath
+     *
+     * @return <tt>true</tt> Darcula L&F is in classpath, <tt>false</tt> otherwise
+     */
+    public static boolean isDarculaLnfInstalled() {
+        return isLnfInstalled(DARCULA_LNF);
+    }
+
     /**
      * Returns whether or not the Pgs L&F is in classpath.
      *
@@ -1838,6 +1854,58 @@ public class LookAndFeelFactory implements ProductNames {
         return _productsUsed;
     }
 
+    /**
+     * As of Java 10, com.sun.java.swing.plaf.windows.WindowsLookAndFeel is no longer available on macOS thus
+     * "instanceof WindowsLookAndFeel" directives will result in a NoClassDefFoundError during runtime. This method
+     * was introduced to avoid this exception.
+     *
+     * @param lnf
+     * @return true if it is a WindowsLookAndFeel.
+     */
+    public static boolean isWindowsLookAndFeel(LookAndFeel lnf) {
+        if (lnf == null) {
+            return false;
+        }
+        else {
+            try {
+                Class c = Class.forName(WINDOWS_LNF);
+                return c.isInstance(lnf);
+            }
+            catch (ClassNotFoundException | NoClassDefFoundError ignore) {
+                // if it is not possible to load the Windows LnF class, the
+                // given lnf instance cannot be an instance of the Windows
+                // LnF class
+                return false;
+            }
+        }
+    }
+
+    /**
+     * As of Java 10, com.sun.java.swing.plaf.windows.WindowsClassicLookAndFeel is no longer available on macOS thus
+     * "instanceof WindowsClassicLookAndFeel" directives will result in a NoClassDefFoundError during runtime. This method
+     * was introduced to avoid this exception.
+     *
+     * @param lnf
+     * @return true if it is a WindowsClassicLookAndFeel.
+     */
+    public static boolean isWindowsClassicLookAndFeel(LookAndFeel lnf) {
+        if (lnf == null) {
+            return false;
+        }
+        else {
+            try {
+                Class c = Class.forName(WINDOWS_CLASSIC_LNF);
+                return c.isInstance(lnf);
+            }
+            catch (ClassNotFoundException | NoClassDefFoundError ignore) {
+                // if it is not possible to load the Windows LnF class, the
+                // given lnf instance cannot be an instance of the Windows
+                // LnF class
+                return false;
+            }
+        }
+    }
+
     /**
      * Sets the products you will use. This is needed so that LookAndFeelFactory knows what UIDefault to initialize. For
      * example, if you use only JIDE Docking Framework and JIDE Grids, you should call
@@ -1865,7 +1933,6 @@ public class LookAndFeelFactory implements ProductNames {
      * Gets the flag indicating if JIDE will try to load the LnF class when {@link #isLnfInstalled(String)} is invoked.
      *
      * @return true if JIDE will try to load the LnF class. Otherwise false
-     *
      * @see #setLoadLookAndFeelClass(boolean)
      * @since 3.2.0
      */
@@ -1882,13 +1949,17 @@ public class LookAndFeelFactory implements ProductNames {
      * you wish.
      *
      * @param loadLookAndFeelClass the flag
-     *
      * @since 3.2.0
      */
     public static void setLoadLookAndFeelClass(boolean loadLookAndFeelClass) {
         _loadLookAndFeelClass = loadLookAndFeelClass;
     }
 
+    public static boolean isMnemonicHidden() {
+        return !UIManager.getBoolean("Button.showMnemonics");
+    }
+
+
     public static void main(String[] args) {
 //        LookAndFeelFactory.setLnfInstalled(AQUA_LNF, false);
 //        System.out.println(LookAndFeelFactory.isLnfInstalled(AQUA_LNF));
