@@ -5,6 +5,9 @@
  */
 package com.jidesoft.utils;
 
+import com.jidesoft.jdk.JdkSpecificClass;
+
+import javax.swing.*;
 import java.awt.*;
 import java.lang.reflect.Field;
 import java.util.Locale;
@@ -527,6 +530,17 @@ final public class SystemInfo {
         return _currentVersion.compareVersion(1.8, 0, 0) >= 0;
     }
 
+    /**
+     * Returns whether or no the JDK version is 1.9 and above.
+     *
+     * @return <tt>true</tt> if the application is running on JDK 1.9 and above, <tt>false</tt> otherwise.
+     * @since 4.0
+     */
+    public static boolean isJdk9Above() {
+        checkJdkVersion();
+        return _currentVersion.compareVersion(9, 0, 0) >= 0;
+    }
+
     /**
      * Returns whether or not the JDK version is exactly the version you are expecting
      *
@@ -654,6 +668,14 @@ final public class SystemInfo {
                         if (s != null && s.trim().length() > 0) _patch = s;
                     }
                 }
+                else { // JDK9 and above
+                    int[] versions = JdkSpecificClass.getVersions();
+                    if (versions != null) {
+                        _majorVersion = versions[0];
+                        _minorVersion = versions[1];
+                        _buildNumber = versions[2];
+                    }
+                }
             }
             catch (NumberFormatException e) {
                 try {
@@ -707,4 +729,20 @@ final public class SystemInfo {
         }
     }
 
+    /**
+     * Gets the state of the hide mnemonic flag. This only has meaning
+     * if this feature is supported by the underlying OS.
+     *
+     * @return true if mnemonics are hidden, otherwise, false
+     * @since 3.7.2
+     */
+    public static boolean isMnemonicHidden() {
+        boolean isMnemonicHidden = true;
+        if (UIManager.getBoolean("Button.showMnemonics")) {
+            // Do not hide mnemonics if the UI defaults do not support this
+            isMnemonicHidden = false;
+        }
+        return isMnemonicHidden;
+    }
+
 }
